@@ -745,6 +745,19 @@ class Range:
         if self.xl is not None:
             return self.xl.select()
 
+    @property
+    def merge_area(self):
+        return Range(self.sheet, self.xl.merge_area.get_address())
+
+    @property
+    def merge_cells(self):
+        return self.xl.merge_cells.get()
+
+    def merge(self, across):
+        self.xl.merge(across=across)
+
+    def unmerge(self):
+        self.xl.unmerge()
 
 class Shape:
     def __init__(self, parent, key):
@@ -1106,7 +1119,7 @@ class Name:
     def refers_to_range(self):
         book = self.parent if isinstance(self.parent, Book) else self.parent.book
         external_address = self.xl.reference_range.get_address(external=True)
-        match = re.search(r"\](.*)!(.*)", external_address)
+        match = re.search(r"\](.*?)'?!(.*)", external_address)
         return Range(Sheet(book, match.group(1)), match.group(2))
 
 
@@ -1212,10 +1225,6 @@ def prepare_xl_data_element(x):
     return x
 
 
-def open_template(fullpath):
-    subprocess.call(['open', fullpath])
-
-
 # --- constants ---
 
 chart_types_k2s = {
