@@ -977,6 +977,20 @@ class Range:
     def select(self):
         return self.xl.Select()
 
+    @property
+    def merge_area(self):
+        return Range(xl=self.xl.MergeArea)
+
+    @property
+    def merge_cells(self):
+        return self.xl.MergeCells
+
+    def merge(self, across):
+        self.xl.Merge(across)
+
+    def unmerge(self):
+        self.xl.UnMerge()
+
 
 def clean_value_data(data, datetime_builder, empty_as, number_builder):
     if number_builder is not None:
@@ -1090,11 +1104,6 @@ def prepare_xl_data_element(x):
         return x
 
 
-# TODO: move somewhere better, same on mac
-def open_template(fullpath):
-    os.startfile(fullpath)
-
-
 class Shape:
 
     def __init__(self, xl):
